# Changelog

<!--next-version-placeholder-->

## v0.13.2 (2022-11-17)
### Fix
* Update ci scripts ([`91f4570`](https://github.com/mrjk/python-project-poetry-template/commit/91f457089da0ce2bcd420c293b5a3398253fdd39))

## v0.13.1 (2022-11-17)
### Fix
* Mike bugs ([`41ecf29`](https://github.com/mrjk/python-project-poetry-template/commit/41ecf2913f8344424b24f8029cc00a61c009d736))
* Mike bugs ([`f30c3ac`](https://github.com/mrjk/python-project-poetry-template/commit/f30c3ac71b0d2ebede4009b65a97046efbdd887c))

## v0.13.0 (2022-11-17)
### Feature
* New feature3 ([`5a0de20`](https://github.com/mrjk/python-project-poetry-template/commit/5a0de20e0dde7f735c707908d088992fbe658f73))
* New feature2 ([`ee92014`](https://github.com/mrjk/python-project-poetry-template/commit/ee920144e9df7f27d09b38a0b253b6ec44d0516b))
* New feature1 ([`94421eb`](https://github.com/mrjk/python-project-poetry-template/commit/94421eb7b0b4b1edca41ffe8e6e84ed2ab3793d7))

### Fix
* Mike bugs ([`4e0ec4e`](https://github.com/mrjk/python-project-poetry-template/commit/4e0ec4e20e07f235aeb3c6625f255a132bc3a929))

## v0.12.3 (2022-11-17)
### Fix
* Mike bugs ([`b3658b4`](https://github.com/mrjk/python-project-poetry-template/commit/b3658b42a20dc5ee9ef957f5c102a6fd92464512))

### Documentation
* Update docs ([`890a002`](https://github.com/mrjk/python-project-poetry-template/commit/890a002cd9354cce1b3ef7fa58b53ae251feb8e4))

## v0.12.2 (2022-11-17)
### Fix
* Mike bugs ([`7b7df65`](https://github.com/mrjk/python-project-poetry-template/commit/7b7df657b4a0db51b887ec5dae70a242fbe83b42))
* Mike bugs ([`1fe26cd`](https://github.com/mrjk/python-project-poetry-template/commit/1fe26cd94702de5c492313206814b56667ff2dce))

## v0.12.1 (2022-11-17)
### Fix
* Simple bug ([`3d8b381`](https://github.com/mrjk/python-project-poetry-template/commit/3d8b3810074afbe0ffe11b792a7056d858aa03d3))

### Documentation
* Add documentation about tooling ([`cbf8cfa`](https://github.com/mrjk/python-project-poetry-template/commit/cbf8cfaf4f563641e688a8fbfb1d3dfdd2341a3f))

## v0.12.0 (2022-11-17)
### Feature
* Support for mike ([`3125c8c`](https://github.com/mrjk/python-project-poetry-template/commit/3125c8c7584d098539c8afb17e529c80984227e2))

## v0.11.11 (2022-11-17)
### Fix
* Ci scripts ([`d78a0fe`](https://github.com/mrjk/python-project-poetry-template/commit/d78a0fe72d648be5066e4ee302335aa400ac4330))
* Old project occurences ([`1478958`](https://github.com/mrjk/python-project-poetry-template/commit/147895837ea5d495ddca820b733ffc3bd088a291))
* Update ci scripts ([`6012679`](https://github.com/mrjk/python-project-poetry-template/commit/6012679eb980cc6733bf112f633c8ee0d664b261))

### Documentation
* Add documentation about tooling ([`bf8be39`](https://github.com/mrjk/python-project-poetry-template/commit/bf8be39e16bc8073fdee81a62697ff09e9150fe4))
* Update docs ([`de0109d`](https://github.com/mrjk/python-project-poetry-template/commit/de0109dbec7856755ce965c576c8aedb6713b5f3))

## v0.11.10 (2022-11-17)
### Fix
* Update ci scripts ([`a0ae9be`](https://github.com/mrjk/python-project-poetry-template/commit/a0ae9be000bffa376121cad68fedc6ebc655f1b1))

## v0.11.9 (2022-11-17)
### Fix
* Update ci scripts ([`7fb2207`](https://github.com/mrjk/python-project-poetry-template/commit/7fb2207cb72b44978f41a37afa859d63beca8b1c))
* Simple bugfix 145sad ([`f162e12`](https://github.com/mrjk/python-project-poetry-template/commit/f162e12c4ae41338db63da2c5975217d4d2e1de4))
* Simple bugfix 145sad ([`7f2fdbc`](https://github.com/mrjk/python-project-poetry-template/commit/7f2fdbcc5ceccd68b8c66ce0aa508e95ae82a49c))
* Simple bugfix 145sad ([`28bcb38`](https://github.com/mrjk/python-project-poetry-template/commit/28bcb38ee87bb1484357702c2b800fcfb042aa6a))

## v0.11.8 (2022-11-17)
### Fix
* Update ci scripts ([`fd5c190`](https://github.com/mrjk/python-project-poetry-template/commit/fd5c1903cc6a9715f9d98ede503cba62ef2d64f6))
* Simple bugfix 145sad ([`b6c8ae5`](https://github.com/mrjk/python-project-poetry-template/commit/b6c8ae547796c9e42a43a7d43e17af2be91e5a79))
* Simple bugfix 145sad ([`87f0827`](https://github.com/mrjk/python-project-poetry-template/commit/87f082783ac7d4ba5aee503dd4236d7b08a70246))
* Simple bugfix 145sad ([`d972eb9`](https://github.com/mrjk/python-project-poetry-template/commit/d972eb999e4a8dfc0bc634276ea7b48f7ea6c5a0))

## v0.11.7 (2022-11-17)
### Fix
* Update ci scripts ([`a66f9ca`](https://github.com/mrjk/python-project-poetry-template/commit/a66f9ca04a8d4001cc62daaf68b4f8322142eef7))
* Update ci scripts ([`d7889ec`](https://github.com/mrjk/python-project-poetry-template/commit/d7889ec9c40bbb3bf010d4dec649bcccd7de3d45))
* Update ci scripts ([`9408b22`](https://github.com/mrjk/python-project-poetry-template/commit/9408b22ed99d0a298c7985dbe398d4d779e83f56))
* Update ci scripts ([`fcf2ae9`](https://github.com/mrjk/python-project-poetry-template/commit/fcf2ae955410f63336b2612c549cd2631565f5ca))

## v0.11.6 (2022-11-17)
### Fix
* Update ci scripts ([`82f237b`](https://github.com/mrjk/python-project-poetry-template/commit/82f237bfcc8dbde173206552975be66281b20264))

## v0.11.5 (2022-11-17)
### Fix
* Update ci scripts ([`f6dea92`](https://github.com/mrjk/python-project-poetry-template/commit/f6dea92234421f5f94b920e41722dd4318e61d5f))
* Publish_github.sh ([`2e0fdbf`](https://github.com/mrjk/python-project-poetry-template/commit/2e0fdbf8b88c62b0a247936a01346ab13bfcc9fe))
* Variable issues ([`fbc00ab`](https://github.com/mrjk/python-project-poetry-template/commit/fbc00abc6a945080fb95ddeb395aa51c40045850))

## v0.11.4 (2022-11-17)
### Fix
* Simple bugfix 145sad ([`407bf91`](https://github.com/mrjk/python-project-poetry-template/commit/407bf918bc6bf4f67803a9e2270689bd0f4dd3e8))
* Simple bugfix 145sad ([`1a5b7ea`](https://github.com/mrjk/python-project-poetry-template/commit/1a5b7ea7723517fcf4f0ef56b3730660835654af))
* Simple bugfix 145sad ([`b961d4b`](https://github.com/mrjk/python-project-poetry-template/commit/b961d4b0a21b65d03450f8fe79a61bdc2df24a6b))

## v0.11.3 (2022-11-17)
### Fix
* Simple bugfix 145sad ([`202a3e3`](https://github.com/mrjk/python-project-poetry-template/commit/202a3e3dd9b2cd5f0fc72823ec7d4bd19e3a1c1e))
* Simple bugfix 145sad ([`11c4a16`](https://github.com/mrjk/python-project-poetry-template/commit/11c4a169ca1cf23d8d4b8ee8096963146bd73358))

## v0.11.2 (2022-11-17)
### Fix
* Simple bugfix 145sad ([`08d23a8`](https://github.com/mrjk/python-project-poetry-template/commit/08d23a88df2af02c77938c6e5b0962c7a99898ed))
* Simple bugfix 145sad ([`9455c64`](https://github.com/mrjk/python-project-poetry-template/commit/9455c64ca9a695771351d082b7cfd89c18017ad3))
* Simple bugfix 145sad ([`b9459b3`](https://github.com/mrjk/python-project-poetry-template/commit/b9459b36bbdfc5654bd024e6f0f984b2cfd1f2b7))

## v0.11.1 (2022-11-17)
### Fix
* Simple bugfix 145sad ([`eb803c7`](https://github.com/mrjk/python-project-poetry-template/commit/eb803c7cc947fdd3765ec25d04b24240cffc8207))
* Simple bugfix 145sad ([`8ba673f`](https://github.com/mrjk/python-project-poetry-template/commit/8ba673f77be9a30c1cec449270f76fcf2132627b))
* Simple bugfix 145sad ([`c9a2724`](https://github.com/mrjk/python-project-poetry-template/commit/c9a272428610157ecf9375eaf92c0ac45ab96c2b))
* Simple bugfix 145sad ([`28626a9`](https://github.com/mrjk/python-project-poetry-template/commit/28626a96cb6fdc8c7d4d4bd8a2e2c87a3e8c3d92))

## v0.11.0 (2022-11-17)


## v0.11.0-beta.1 (2022-11-17)
### Feature
* Add direnv support with secrets ([`846cd1c`](https://github.com/mrjk/python-project-poetry-template/commit/846cd1c63cf6526dd6fd1352adbb2a5ddae33991))

## v0.10.9 (2022-11-17)
### Fix
* Gh upload script ([`18abc1e`](https://github.com/mrjk/python-project-poetry-template/commit/18abc1e6cc59a6e805ff7238649c065c8071ca0f))

## v0.10.9-beta.14 (2022-11-16)
### Fix
* Wip ([`f541703`](https://github.com/mrjk/python-project-poetry-template/commit/f54170331b2b9b7a6b0d5d43283d62aebfbb3f70))

## v0.10.9-beta.13 (2022-11-16)
### Fix
* Simple bugfix 92 ([`a6fd8bc`](https://github.com/mrjk/python-project-poetry-template/commit/a6fd8bcb218abe40398d0440c7bca9f41e000ac0))
* Simple bugfix 86 ([`cb21375`](https://github.com/mrjk/python-project-poetry-template/commit/cb21375fbfd29b584da2940855581ad38c4c1ffc))
* Simple bugfix 54 ([`cdb76a9`](https://github.com/mrjk/python-project-poetry-template/commit/cdb76a98c0c57e236cfc375a0984cde90fc4c5f6))
* Simple bugfix 1 ([`84319fa`](https://github.com/mrjk/python-project-poetry-template/commit/84319fa864cdf3608cdf6e175a90bab69a1a42c8))

## v0.10.9-beta.12 (2022-11-16)
### Fix
* Simple bugfix 92 ([`7059f94`](https://github.com/mrjk/python-project-poetry-template/commit/7059f943ecaf7e400012952acc4a1e9aed0f0195))
* Simple bugfix 86 ([`9e2f430`](https://github.com/mrjk/python-project-poetry-template/commit/9e2f430c9936c53b7addcc0e0696a5448bde7b62))
* Simple bugfix 54 ([`742f070`](https://github.com/mrjk/python-project-poetry-template/commit/742f07048a6336a8adc70373f6b4b0855b1a513b))
* Simple bugfix 1 ([`3a7f5d3`](https://github.com/mrjk/python-project-poetry-template/commit/3a7f5d31cca52e80908ddb5c666e768f7fa3574d))

## v0.10.9-beta.11 (2022-11-16)
### Feature
* Complete the CI scripts ([`94eb0cf`](https://github.com/mrjk/python-project-poetry-template/commit/94eb0cfe485f775cd63bbe595b37cd88545d4941))
* Update code ([`b327f73`](https://github.com/mrjk/python-project-poetry-template/commit/b327f739e347a1f49ac5c15039a796b5fa43052f))
* New feat ([`b4578e4`](https://github.com/mrjk/python-project-poetry-template/commit/b4578e4b170618e72534397da61e18f81790cb0d))
* New feat ([`c714a1c`](https://github.com/mrjk/python-project-poetry-template/commit/c714a1c48ba2c9ecb7bdd88b0c73f171334c7904))
* New feat ([`3e0b959`](https://github.com/mrjk/python-project-poetry-template/commit/3e0b9591f5a8019fd86d7939bf5bbc663633791d))
* Script to schow version ([`1380a82`](https://github.com/mrjk/python-project-poetry-template/commit/1380a82ab3ffdf12cae1fd41a119aa411090c028))
* New feat ([`bcd3cf5`](https://github.com/mrjk/python-project-poetry-template/commit/bcd3cf592b119145dd18516aeeb967a1c6f028e3))
* New feat ([`b12c159`](https://github.com/mrjk/python-project-poetry-template/commit/b12c159d32cbd6960cb14a6d4aa3f644b5742c8a))
* New feat ([`5ae395c`](https://github.com/mrjk/python-project-poetry-template/commit/5ae395c04a600c45991c1b803454f518f5507911))
* New feat ([`d081df8`](https://github.com/mrjk/python-project-poetry-template/commit/d081df8af0307c57e209623c865ad2f2ee4e6d72))
* New feat ([`b1e92d4`](https://github.com/mrjk/python-project-poetry-template/commit/b1e92d487d1f1106fde81eda947fb0ef258dfa99))
* New feat ([`9d273d2`](https://github.com/mrjk/python-project-poetry-template/commit/9d273d22ccc85b2810d517c49fa057f4aa024919))
* New feat ([`d10ffc7`](https://github.com/mrjk/python-project-poetry-template/commit/d10ffc760cf55c318b548b795be33d75e308f147))
* New feat ([`1ac722b`](https://github.com/mrjk/python-project-poetry-template/commit/1ac722b3b9365abea433e8648dd77d4034b21d7b))
* New feat ([`d33b277`](https://github.com/mrjk/python-project-poetry-template/commit/d33b277a02fa580d5855dd0eaca27c53f4c25d54))
* New feat ([`4e3499c`](https://github.com/mrjk/python-project-poetry-template/commit/4e3499cfde2f3dac741ed14515c3329be6307e4c))
* New feat ([`b70bf17`](https://github.com/mrjk/python-project-poetry-template/commit/b70bf17237b048e179b58aa1b31a3ead5253d060))
* New feat ([`33249f1`](https://github.com/mrjk/python-project-poetry-template/commit/33249f17e6d6cbb40e72c7e29c1b29c25abe4685))
* Add new feat ([`a1662ed`](https://github.com/mrjk/python-project-poetry-template/commit/a1662edc46965e1be05e58e6b74ba101f16e9ef3))
* Add new feat ([`28325c8`](https://github.com/mrjk/python-project-poetry-template/commit/28325c8a492a2ad45565a47791adc28d5a3b6e08))
* Add new feat ([`bbe34b6`](https://github.com/mrjk/python-project-poetry-template/commit/bbe34b6b9900dffff6fb8130e9cb3fee070182ab))
* Add new feat ([`a1f995f`](https://github.com/mrjk/python-project-poetry-template/commit/a1f995fcae5efbd13bba81d30bdcec76a72d2219))
* Add new feat ([`4bd4157`](https://github.com/mrjk/python-project-poetry-template/commit/4bd41576dd21eba7277aa81149556f7db0416f13))
* Change 2 ([`9032e29`](https://github.com/mrjk/python-project-poetry-template/commit/9032e2907b495bd543cd85d538d48f5f9cf33172))
* Change 1 ([`2b8aa22`](https://github.com/mrjk/python-project-poetry-template/commit/2b8aa225d82ee340201b20a26855b0e9acd327be))
* Change 0 ([`947d532`](https://github.com/mrjk/python-project-poetry-template/commit/947d53228bec50c632810e87c6f2a73dbf673572))
* Change 1 ([`f08663b`](https://github.com/mrjk/python-project-poetry-template/commit/f08663b4b1b1cb14205fe0c8cf8b5b2ecb3778d0))
* Change 0 ([`44cf1e0`](https://github.com/mrjk/python-project-poetry-template/commit/44cf1e0ac9a0e2c6ea17ee8b51f6302a6f19f7e7))
* Change 1 ([`c7b9869`](https://github.com/mrjk/python-project-poetry-template/commit/c7b9869da40002fbc6e30140407d8e9620559470))
* Change 0 ([`058d581`](https://github.com/mrjk/python-project-poetry-template/commit/058d5816cca2ff9d706317782c32d4f61e6da8ed))
* Change 1 ([`0bf9fdf`](https://github.com/mrjk/python-project-poetry-template/commit/0bf9fdf8a381f9d189131793744db4e0cb517402))
* Change 0 ([`23be3d3`](https://github.com/mrjk/python-project-poetry-template/commit/23be3d3bd073b6f6768dc3417e0f743a009f258b))
* Change 1 ([`4cc5d64`](https://github.com/mrjk/python-project-poetry-template/commit/4cc5d64728d08d443ee3e7cfba00f079d38ac77f))
* Change 0 ([`03a9a27`](https://github.com/mrjk/python-project-poetry-template/commit/03a9a276fa313e93369f55dcc4ca64b4f2014e35))
* Change 1 ([`7ab30e4`](https://github.com/mrjk/python-project-poetry-template/commit/7ab30e408d1bcc38b1a22298b87f8fff658ec46b))
* Change 0 ([`b843154`](https://github.com/mrjk/python-project-poetry-template/commit/b843154acc1ec3ffeb74f90ee9e968775fd0dceb))
* Change 1 ([`9367ae7`](https://github.com/mrjk/python-project-poetry-template/commit/9367ae769766ccdbceceb69b167b6001142fd7c7))
* Change 0 ([`dc74738`](https://github.com/mrjk/python-project-poetry-template/commit/dc74738c6e6bdefffbbad00924f239071be82195))
* Change 1 ([`1183646`](https://github.com/mrjk/python-project-poetry-template/commit/11836468bd308e5e223bccc3211d306575f00e76))
* Change 0 ([`baa2f02`](https://github.com/mrjk/python-project-poetry-template/commit/baa2f02318c930444b2ef4130eeab3093027754a))
* Change 1 ([`8e7d4d3`](https://github.com/mrjk/python-project-poetry-template/commit/8e7d4d3dc545afbad496e83b9ec2c6e2992d3480))
* Change 0 ([`8b3a601`](https://github.com/mrjk/python-project-poetry-template/commit/8b3a601476ff8a944b77837974228ad2c09ef2e6))
* Change 1 ([`f0b8e47`](https://github.com/mrjk/python-project-poetry-template/commit/f0b8e4752d25e1db925a8a9b9968d489f4cdf76d))
* Change 0 ([`8e98ea8`](https://github.com/mrjk/python-project-poetry-template/commit/8e98ea865419c3d471591876ad45ad02fe0a8f5f))
* Change 1 ([`f0ab652`](https://github.com/mrjk/python-project-poetry-template/commit/f0ab652441a1f38c2eb3cc20fad1580844ae615c))
* Change 0 ([`5563940`](https://github.com/mrjk/python-project-poetry-template/commit/556394083e482f1868c20e6a338ceea0d053f231))
* Change 1 ([`271705f`](https://github.com/mrjk/python-project-poetry-template/commit/271705f44781e7ba4da4709593ba62ccc74e8218))
* Change 0 ([`28e9ca4`](https://github.com/mrjk/python-project-poetry-template/commit/28e9ca4ab45ff7aa0fedd54dae4154072bafad16))
* Change 1 ([`eeb87d4`](https://github.com/mrjk/python-project-poetry-template/commit/eeb87d486540373111399bc57b3778dc7ee85006))
* Change 0 ([`db64650`](https://github.com/mrjk/python-project-poetry-template/commit/db64650b58cec2654eb16e7a091189d8d36b55fc))
* Change 1 ([`4bac515`](https://github.com/mrjk/python-project-poetry-template/commit/4bac5155f0b5e7d953ddf8e3fd9d47bfbc6fee0b))
* Change 0 ([`3fc8540`](https://github.com/mrjk/python-project-poetry-template/commit/3fc8540b1999b7671e28179496bec3083c0b4400))
* Change 1 ([`2badc94`](https://github.com/mrjk/python-project-poetry-template/commit/2badc94c4a658ab58659e44e194330d1205043bd))
* Change 0 ([`ea8d9b7`](https://github.com/mrjk/python-project-poetry-template/commit/ea8d9b7d29d8198a80e105c271d147bdb21becc9))
* Change 1 ([`a8dabdc`](https://github.com/mrjk/python-project-poetry-template/commit/a8dabdc826682aa4e854967690d91c1886360235))
* Change 0 ([`8ac49cf`](https://github.com/mrjk/python-project-poetry-template/commit/8ac49cf234c43b66f5772b586bdb13825cb604be))
* Change 1 ([`507bb93`](https://github.com/mrjk/python-project-poetry-template/commit/507bb93c2774ef7479378aa0197b12f7047c0608))
* Change 0 ([`f5f2125`](https://github.com/mrjk/python-project-poetry-template/commit/f5f21251054f3baf9127fc86ee4a41f6dbdd1b36))
* Change 1 ([`64485bd`](https://github.com/mrjk/python-project-poetry-template/commit/64485bd1099e06aafb10911d2b1427c936f38243))
* Change 0 ([`4a5a961`](https://github.com/mrjk/python-project-poetry-template/commit/4a5a961ddfd622a481ad417f94f0522aefcd6b67))
* Change 1 ([`a2f6675`](https://github.com/mrjk/python-project-poetry-template/commit/a2f667534736685213934c342e03c90466c533b5))
* Change 0 ([`40a9503`](https://github.com/mrjk/python-project-poetry-template/commit/40a9503ceb9f6ff8a89f01e929193177f5574553))
* Change 1 ([`70e1341`](https://github.com/mrjk/python-project-poetry-template/commit/70e13415f5fb03f695c22004198a88ef22368130))
* Change 0 ([`8dc1976`](https://github.com/mrjk/python-project-poetry-template/commit/8dc1976cf541ed80b6cdfee559ac327d3e692e65))
* Change 1 ([`0adf32e`](https://github.com/mrjk/python-project-poetry-template/commit/0adf32e8c18b9e5a3c0d46feb78ca558e7b2fa1b))
* Change 0 ([`5445254`](https://github.com/mrjk/python-project-poetry-template/commit/5445254b1dbee2e42dc869a545e9f00743dd7e32))
* Change 1 ([`2c7f020`](https://github.com/mrjk/python-project-poetry-template/commit/2c7f0200ebedf9597c63c7e3ffd73ad451edefd1))
* Change 0 ([`e6433b0`](https://github.com/mrjk/python-project-poetry-template/commit/e6433b0ac0587ab10f71516f0a6372db9257d126))
* Change 1 ([`2a23c9b`](https://github.com/mrjk/python-project-poetry-template/commit/2a23c9b68ce0aee48353ed1b31cf1bc1d86ac847))
* Change 0 ([`8e3bd16`](https://github.com/mrjk/python-project-poetry-template/commit/8e3bd1628f772c6e650ad31cb91c0e47640e9767))
* Change 1 ([`946701d`](https://github.com/mrjk/python-project-poetry-template/commit/946701d5c26c12410d1049df4e499c7f898beba2))
* Change 0 ([`e72ff8c`](https://github.com/mrjk/python-project-poetry-template/commit/e72ff8c822330669e95ec57963c921d299375cdd))
* Change 1 ([`6f7b6e3`](https://github.com/mrjk/python-project-poetry-template/commit/6f7b6e384fbee5bc9866ca6cc8583dc2abc56763))
* Change 0 ([`411677e`](https://github.com/mrjk/python-project-poetry-template/commit/411677efd75f0a031c3669f3bea31bd9bbd681a0))
* Change 1 ([`4d1373b`](https://github.com/mrjk/python-project-poetry-template/commit/4d1373b9620fd8f9b2c8451d0566e4a820e8d269))
* Change 0 ([`50f2559`](https://github.com/mrjk/python-project-poetry-template/commit/50f25593c0f0c62e59a66251fddfcdbaa66fb760))
* Change 1 ([`b6a358c`](https://github.com/mrjk/python-project-poetry-template/commit/b6a358ca57c4aeb529b7775deb5aaa7a832cf1b1))
* Change 0 ([`5d0dbdc`](https://github.com/mrjk/python-project-poetry-template/commit/5d0dbdcccf2b49a50d625bd6a2c791494f8e40fe))
* Change 1 ([`036e21f`](https://github.com/mrjk/python-project-poetry-template/commit/036e21f1f75808b3c7e01df9f100c25efc8dc817))
* Change 0 ([`b00ad35`](https://github.com/mrjk/python-project-poetry-template/commit/b00ad35378c871a15d258c725c11808bc5ed40c8))
* Change 1 ([`f9f2aba`](https://github.com/mrjk/python-project-poetry-template/commit/f9f2aba980f54ca9e3b66610790af03fe9c4d2f4))
* Change 0 ([`18f423b`](https://github.com/mrjk/python-project-poetry-template/commit/18f423b68eafb8a3333ebe22b1adf3dd24bc14f2))
* Change 1 ([`7114e82`](https://github.com/mrjk/python-project-poetry-template/commit/7114e829f7268c77717cb114522cfbc6304656fb))
* Change 0 ([`c878e5e`](https://github.com/mrjk/python-project-poetry-template/commit/c878e5ea61ed32b309fb0321881b7dd529487e68))

### Fix
* WIP release ([`995fb1f`](https://github.com/mrjk/python-project-poetry-template/commit/995fb1f7bd18fe1101cd0a2937eb16fd4c36808a))
* WIP release ([`7827789`](https://github.com/mrjk/python-project-poetry-template/commit/782778909f09a620ee53644e37522969658c8ac4))
* Simple bugfix 92 ([`326e83c`](https://github.com/mrjk/python-project-poetry-template/commit/326e83c2a7cbca167ec897225a78b2c995bbf218))
* Simple bugfix 86 ([`48dc6d9`](https://github.com/mrjk/python-project-poetry-template/commit/48dc6d9e9ce5f68bec70ba3cf78c4fcf294f8482))
* Simple bugfix 54 ([`e1d6a79`](https://github.com/mrjk/python-project-poetry-template/commit/e1d6a79d121d07e81b107a489e28c53af46a3eaf))
* Simple bugfix 1 ([`8fe03dd`](https://github.com/mrjk/python-project-poetry-template/commit/8fe03ddbc857e789e4e890995cad1405e6713a25))
* WIP release ([`b034ffb`](https://github.com/mrjk/python-project-poetry-template/commit/b034ffbfec19c6b5059c931fad369a03788488fc))
* Simple bugfix 145sad ([`aa68761`](https://github.com/mrjk/python-project-poetry-template/commit/aa687612cab7a3180373ba394513aa75297f06b8))
* Simple bugfix 145sad ([`0be2be4`](https://github.com/mrjk/python-project-poetry-template/commit/0be2be480a2fccaf17ada031ed5ac129761462a4))
* Simple bugfix 145sad ([`bb8c1a8`](https://github.com/mrjk/python-project-poetry-template/commit/bb8c1a87aab4831fae719534a6954b181c3ca37b))
* Simple bugfix 145sad ([`8887184`](https://github.com/mrjk/python-project-poetry-template/commit/88871848974523563a9b77768429aa2b2e4be2e9))
* Disable github release ([`f842c22`](https://github.com/mrjk/python-project-poetry-template/commit/f842c22fd8032418c959680761aeac7c27968309))
* Disable github release ([`3686e8f`](https://github.com/mrjk/python-project-poetry-template/commit/3686e8f2ad24143e7a418a8d6c53b4e135325e38))
* Disable github release ([`69b5f5f`](https://github.com/mrjk/python-project-poetry-template/commit/69b5f5f980b49e720c6ed81b8608f85f88fff9ba))
* Disable github release ([`8c2a5d2`](https://github.com/mrjk/python-project-poetry-template/commit/8c2a5d2a688d1d3c88d5ba488b7b38c3eff73622))
* Ci ([`acd7d38`](https://github.com/mrjk/python-project-poetry-template/commit/acd7d38efec6f5f6c83292a8cd4a98e7295a7dc1))
* Ci ([`e847ce2`](https://github.com/mrjk/python-project-poetry-template/commit/e847ce2860797fc1fe8d4a38d60eb03760f0c061))
* Ci ([`95cd6f3`](https://github.com/mrjk/python-project-poetry-template/commit/95cd6f33928eaea6d6d3be375a72194afcfdf118))
* Ci ([`455753e`](https://github.com/mrjk/python-project-poetry-template/commit/455753e0003c0f4134b4369f38ea1949e7b074b2))
* Ci ([`906e835`](https://github.com/mrjk/python-project-poetry-template/commit/906e8350bdfdbbc1e80ffa51651f8e9af9696045))
* Simple bugfix 145sad ([`8f30070`](https://github.com/mrjk/python-project-poetry-template/commit/8f300706d824fb30da7e0c44d57f062a8758e44c))
* Simple bugfix 145 ([`af0496a`](https://github.com/mrjk/python-project-poetry-template/commit/af0496ae17830f014caa09eedd38f65a169c253e))
* Simple bugfix 11 ([`d716524`](https://github.com/mrjk/python-project-poetry-template/commit/d716524a8dfd8004ab1740814c1c3211ab8e9994))
* Simple bugfix 10 ([`93c284e`](https://github.com/mrjk/python-project-poetry-template/commit/93c284e39e9da0c3e40a3f8a1c876f3ab3160732))
* Simple bugfix3 ([`c374ffe`](https://github.com/mrjk/python-project-poetry-template/commit/c374ffe7b79f5864568c6f2610137d2fe0c6a4e2))
* Simple bugfix3 ([`76cae9b`](https://github.com/mrjk/python-project-poetry-template/commit/76cae9b85aa64b7a655e4cf87eee640783173840))
* Simple bugfix3 ([`05a3741`](https://github.com/mrjk/python-project-poetry-template/commit/05a374165235515c42835bbad1a7afca6a16565b))
* Simple bugfix3 ([`d34655f`](https://github.com/mrjk/python-project-poetry-template/commit/d34655f7f66513ef5297d9c97c9a9640f9c36644))
* Simple bugfix3 ([`92ee020`](https://github.com/mrjk/python-project-poetry-template/commit/92ee020fddf94abf391115b28916113f9774b528))
* Simple bugfix2 ([`dba214a`](https://github.com/mrjk/python-project-poetry-template/commit/dba214ae4b90ee68e33f4a1f748022cdff2a8dc8))
* Simple bugfix1 ([`ce0a5a2`](https://github.com/mrjk/python-project-poetry-template/commit/ce0a5a23422a49c4a6b4cdc97f56917e370280ed))
* Simple bugfix1 ([`1cc83c4`](https://github.com/mrjk/python-project-poetry-template/commit/1cc83c450fd7af2d738ea52d6928f43a66d6566f))
* Simple bugfix2 ([`22407eb`](https://github.com/mrjk/python-project-poetry-template/commit/22407eb444f845e5a6485bd7d1b4a90e24d21c32))
* Simple bugfix3 ([`d071adb`](https://github.com/mrjk/python-project-poetry-template/commit/d071adba52efb1066cfb7361f696487c8748be8e))
* Ci ([`badaa60`](https://github.com/mrjk/python-project-poetry-template/commit/badaa60635ea9d8d44941c79902b8410339fc6f3))
* GH workflow ([`e7ce38d`](https://github.com/mrjk/python-project-poetry-template/commit/e7ce38d36abd65d5646fb01574c52b20de96c5d0))
* GH workflow ([`275c598`](https://github.com/mrjk/python-project-poetry-template/commit/275c59815e28f181478353e43be712f123b5d8f9))
* GH workflow ([`5a12c01`](https://github.com/mrjk/python-project-poetry-template/commit/5a12c01b606589b35cf894f1735002a5c7559c4c))
* Taskfile ([`cc8f970`](https://github.com/mrjk/python-project-poetry-template/commit/cc8f9704ebb4a5c5e5ba1a778b556a5e2e462ebb))
* Taskfile release process ([`6bdf1d3`](https://github.com/mrjk/python-project-poetry-template/commit/6bdf1d39747a9dd80d452c5ddebf4bc9df2bc1d2))
* Simple bugfix3 ([`9b0b97e`](https://github.com/mrjk/python-project-poetry-template/commit/9b0b97e8de6cf05778faacd554841cda635d6bad))
* GH workflow ([`9b89070`](https://github.com/mrjk/python-project-poetry-template/commit/9b8907015abd3d92a2d02d422ea0fca4db0cdcb3))
* GH workflow ([`0a4673d`](https://github.com/mrjk/python-project-poetry-template/commit/0a4673d42af6835ad49b882e32f6dad84dc6a36a))
* GH workflow ([`d3debe2`](https://github.com/mrjk/python-project-poetry-template/commit/d3debe2ad6168a8cd9c4715f92342555d3bf1271))
* GH workflow ([`b7bfecb`](https://github.com/mrjk/python-project-poetry-template/commit/b7bfecba46e41c29995fd25bcf64ec4438af3d38))
* GH workflow ([`db161ec`](https://github.com/mrjk/python-project-poetry-template/commit/db161ecefaf3476886ae99e769ec8682b9a86617))
* GH workflow ([`070fdd9`](https://github.com/mrjk/python-project-poetry-template/commit/070fdd900ab9156c563095ac271247a8ab4688df))
* Simple bugfix3 ([`1458569`](https://github.com/mrjk/python-project-poetry-template/commit/1458569fa788dc33bb348ef92bdb90f7f1ba029a))
* Simple bugfix2 ([`f6169cd`](https://github.com/mrjk/python-project-poetry-template/commit/f6169cd251d697f700d2e71a43d6d08c3954edf5))
* Simple bugfix1 ([`e83b262`](https://github.com/mrjk/python-project-poetry-template/commit/e83b2628392d631fd82faf0d9eb7755b3eb96d52))
* Taskfile ([`a270e15`](https://github.com/mrjk/python-project-poetry-template/commit/a270e15ab2228f996c063418c74d42510d736123))
* GH workflow ([`0f96138`](https://github.com/mrjk/python-project-poetry-template/commit/0f9613813a996958fb31480688ac130e1e3e2896))
* GH workflow ([`d6b74ad`](https://github.com/mrjk/python-project-poetry-template/commit/d6b74ad00df4006035337919ed1eb8f19ed09198))
* GH workflow ([`b54959c`](https://github.com/mrjk/python-project-poetry-template/commit/b54959c6879f317ef4a4a9285171114c5fb962b9))
* GH workflow ([`53cf1ca`](https://github.com/mrjk/python-project-poetry-template/commit/53cf1ca512f35717b8cc4f7f791a2f36c1f372ce))
* GH workflow ([`0333f61`](https://github.com/mrjk/python-project-poetry-template/commit/0333f611b8b29723839934696a827f5dc8317bd3))
* GH workflow ([`5bb16bf`](https://github.com/mrjk/python-project-poetry-template/commit/5bb16bf11a9c1d8675887ed2659ebcd9b4b93ba4))
* GH workflow ([`0137c74`](https://github.com/mrjk/python-project-poetry-template/commit/0137c741317714ddb509cd5f944fd25d985e599c))
* GH workflow ([`4a1b5eb`](https://github.com/mrjk/python-project-poetry-template/commit/4a1b5eb24f666dd2681da51029340e54f03a4568))
* GH workflow ([`95d42f6`](https://github.com/mrjk/python-project-poetry-template/commit/95d42f60d8618d826311efe311648c3fe14373d8))
* GH workflow ([`6e1f8c8`](https://github.com/mrjk/python-project-poetry-template/commit/6e1f8c845c00955e523312daa12dd6e4b2bfe94c))
* GH workflow ([`ccb8324`](https://github.com/mrjk/python-project-poetry-template/commit/ccb83240de22699787561ace3ac9b7b6178eeb46))
* GH workflow ([`f7d72e7`](https://github.com/mrjk/python-project-poetry-template/commit/f7d72e7fe37e8c94187c393ae6238e31d86842cd))
* GH workflow ([`ae715eb`](https://github.com/mrjk/python-project-poetry-template/commit/ae715ebc9e9700e7d7f5f3be098dcc5f1470cfa5))
* GH workflow ([`09519a1`](https://github.com/mrjk/python-project-poetry-template/commit/09519a147bdce2e7aabdfc11dad99df193eb4bd7))
* GH workflow ([`3ca1ea4`](https://github.com/mrjk/python-project-poetry-template/commit/3ca1ea42e3a2a08a922965ea6c59d73ba6207df1))
* GH workflow ([`eabc0b0`](https://github.com/mrjk/python-project-poetry-template/commit/eabc0b059edc7575d95b8cb149dead1acf8b695a))
* GH workflow ([`8edbfe7`](https://github.com/mrjk/python-project-poetry-template/commit/8edbfe770255a4a91a46cf69338737f8411c988f))
* GH workflow ([`776ac16`](https://github.com/mrjk/python-project-poetry-template/commit/776ac166b9663826752f8b9e98d1026936fd6955))
* GH workflow ([`3f01e7c`](https://github.com/mrjk/python-project-poetry-template/commit/3f01e7c971cb7135f1fddce287d8f72751483b23))
* GH workflow ([`7ba7703`](https://github.com/mrjk/python-project-poetry-template/commit/7ba770308e6c2dc67ee4be75eb598288ea6ee8dc))
* GH workflow ([`def11fc`](https://github.com/mrjk/python-project-poetry-template/commit/def11fc372ba61c676f34ebe3e95a1a749f42da4))
* GH workflow ([`f463c22`](https://github.com/mrjk/python-project-poetry-template/commit/f463c22ec36f4041fa3ff3bdb54d4778c777c5d2))
* GH workflow ([`7c96545`](https://github.com/mrjk/python-project-poetry-template/commit/7c96545ac9e5ff6b916c79c925daa7cbbb75278d))
* Missing .gitignore ([`59de782`](https://github.com/mrjk/python-project-poetry-template/commit/59de7829c18986bfdc783b2b3446d7d817270b4d))
* Little errors ([`2eaead9`](https://github.com/mrjk/python-project-poetry-template/commit/2eaead9ee35b77ca182f30867bb3ed26e37fe25f))
* Extra VERSION_NOTES.md.md file ([`39e9330`](https://github.com/mrjk/python-project-poetry-template/commit/39e93304740f6e3a908a505f6dfbb15e361bc377))
* Simple bug ([`211f0b8`](https://github.com/mrjk/python-project-poetry-template/commit/211f0b82cdc01b3ad5e9c59a5d0ee0b1a62bd34e))
* Simple bug ([`f742d6d`](https://github.com/mrjk/python-project-poetry-template/commit/f742d6d529ef663f0b2f784dc02d0adda4c0a7eb))
* Simple bug ([`4304b89`](https://github.com/mrjk/python-project-poetry-template/commit/4304b89dd19b5639adf1a2efb2e76e2b2a0129df))
* Little errors ([`df3a4e2`](https://github.com/mrjk/python-project-poetry-template/commit/df3a4e28d309f063d19e4fd303fd411dc437c7dd))
* Remove old LAST_CHANGES.md ([`498600a`](https://github.com/mrjk/python-project-poetry-template/commit/498600ae142324b7bd2684ab322929fbab9a2915))
* Little errors ([`4aa4ccc`](https://github.com/mrjk/python-project-poetry-template/commit/4aa4ccc9b55b90591a1c2f4587a42e8fc32d5285))
* Little errors ([`f2b0511`](https://github.com/mrjk/python-project-poetry-template/commit/f2b0511ce37c0ba8783de2627a6d76ba37a55273))
* Little errors ([`8893dc2`](https://github.com/mrjk/python-project-poetry-template/commit/8893dc2fc8e89fc12df9620c3d9d3d316f802fee))
* Missing RELEASE.md ([`8efd20e`](https://github.com/mrjk/python-project-poetry-template/commit/8efd20ebfa603068c457d42e0de7f1f769c61da5))
* Missing RELEASE.md ([`2d4079c`](https://github.com/mrjk/python-project-poetry-template/commit/2d4079cf989bcb1611c96ae6e9ce9b8a2417098f))
* Ci ([`5662bb0`](https://github.com/mrjk/python-project-poetry-template/commit/5662bb0d161b9a34abc30d14025b280800cb7309))
* Ci ([`069facf`](https://github.com/mrjk/python-project-poetry-template/commit/069facfdb05f894e4552cd23dc12ef1b91a70725))
* Ci ([`dea286a`](https://github.com/mrjk/python-project-poetry-template/commit/dea286a65ec6eeca0cf9a373f09b2de8acc65162))
* Ci ([`50015ae`](https://github.com/mrjk/python-project-poetry-template/commit/50015aebd641b1dc1d618cc7f94b90a70fd3ab15))
* Simple bug ([`299395c`](https://github.com/mrjk/python-project-poetry-template/commit/299395c6cb7b2a7a393b8923a1f087894b12eeb1))
* Simple bug ([`8ea91fc`](https://github.com/mrjk/python-project-poetry-template/commit/8ea91fc7bc67b704efc7ee683ced8f9a23118d47))
* Ci ([`6fe1690`](https://github.com/mrjk/python-project-poetry-template/commit/6fe169096ffc635312d81672284ee2ef64721968))
* Ci ([`65a86d6`](https://github.com/mrjk/python-project-poetry-template/commit/65a86d6ba4339e74beb8d7c764cbaeb98eeae168))
* Ci ([`2c70f60`](https://github.com/mrjk/python-project-poetry-template/commit/2c70f607617bab5b735d0bf7b61b62da5aa19f66))
* Ci ([`c48b089`](https://github.com/mrjk/python-project-poetry-template/commit/c48b089fb7bf492d628ed98aeeda9a98abb4eb0b))
* Ci ([`60eeb18`](https://github.com/mrjk/python-project-poetry-template/commit/60eeb184a6e18e9297951e7d83f8866cba7eaf16))
* RELEASES files ([`3aacc7f`](https://github.com/mrjk/python-project-poetry-template/commit/3aacc7f12ee43830e4254ffeb47ef252be3c462e))
* RELEASE.md location ([`4909fe5`](https://github.com/mrjk/python-project-poetry-template/commit/4909fe5a09f1a1fd24ba04418a1ab245cf0966dc))
* Ci ([`c2f4264`](https://github.com/mrjk/python-project-poetry-template/commit/c2f4264172b6b5ba4aa07f077720f4f2c33a3d06))
* Simple bug ([`8db12c5`](https://github.com/mrjk/python-project-poetry-template/commit/8db12c59ca4aa280501e47ddf6be2709e02874ba))
* Simple bug ([`635195b`](https://github.com/mrjk/python-project-poetry-template/commit/635195beed0d842c6ac7472fabc0a9188231471b))
* Simple bug ([`4ce61c2`](https://github.com/mrjk/python-project-poetry-template/commit/4ce61c274d10e9e751f5cbb72c43457bcf48b8b3))
* Missing REALEASE.md ([`f76cd3a`](https://github.com/mrjk/python-project-poetry-template/commit/f76cd3ae070dfe4c214940fa5944073a75c394fa))
* Simple bug ([`1394e62`](https://github.com/mrjk/python-project-poetry-template/commit/1394e62e2163ee1c14864e9139a3c0a9cf75890f))
* Simple bug ([`6c575ee`](https://github.com/mrjk/python-project-poetry-template/commit/6c575eeabba36ca82b235cf0e873c18efdeccce1))
* Simple bug ([`b3b8e09`](https://github.com/mrjk/python-project-poetry-template/commit/b3b8e0941f0052fc0c1b573b63fc1c8b02ee658a))
* Simple bug ([`5f37952`](https://github.com/mrjk/python-project-poetry-template/commit/5f37952c5570babf33b8f62fe33ac919cac1b658))
* Simple bug ([`f809a87`](https://github.com/mrjk/python-project-poetry-template/commit/f809a873e90acdc8cdc19664467564cb074adde6))
* Simple bug ([`2fae86c`](https://github.com/mrjk/python-project-poetry-template/commit/2fae86c1fc3c30a2a3d18072b48cecc8f8662f69))
* Simple bug ([`13f20ed`](https://github.com/mrjk/python-project-poetry-template/commit/13f20ede4725a980c41de6623664a70567f5bf8e))
* Simple bug ([`c02164d`](https://github.com/mrjk/python-project-poetry-template/commit/c02164d0eec4b1bf1766cacee65db7dc33141241))
* Simple bug ([`284272b`](https://github.com/mrjk/python-project-poetry-template/commit/284272b202ffc746531bb6f9b12e94bcde0c8354))
* Dist cleaning ([`eaf0dec`](https://github.com/mrjk/python-project-poetry-template/commit/eaf0dec0929119980c151b96f607ed3ef87a96aa))
* Simple bug ([`9de7690`](https://github.com/mrjk/python-project-poetry-template/commit/9de7690c03b351e59c807902beff576fd1fea710))
* Simple bug ([`35b5747`](https://github.com/mrjk/python-project-poetry-template/commit/35b57474352bb085c592c461c34ea898818145dc))
* Simple bug ([`ec9f71d`](https://github.com/mrjk/python-project-poetry-template/commit/ec9f71d3235a713da2b271308e25165d0c9a39b7))
* Simple bug ([`7ffd970`](https://github.com/mrjk/python-project-poetry-template/commit/7ffd970161b465cb1d48f11e0e6d614aeeb40fe2))
* Simple bug ([`034206a`](https://github.com/mrjk/python-project-poetry-template/commit/034206a1b660d467409828537e1a4a86e2c176db))
* Simple bug ([`e5ae652`](https://github.com/mrjk/python-project-poetry-template/commit/e5ae652e4206a8de0bcbbd3980b5e8ce2ad021d2))
* Simple bug ([`accd9ea`](https://github.com/mrjk/python-project-poetry-template/commit/accd9ea0ea0e3180c27c974e67552edfec02704f))
* Simple bug ([`1876550`](https://github.com/mrjk/python-project-poetry-template/commit/1876550e312ab5a40243d8c032dc86aaa9e19303))
* Simple bug ([`78440d7`](https://github.com/mrjk/python-project-poetry-template/commit/78440d78117415a29b73a0aff3715910cf865e9c))
* Simple bug ([`7bcb3c0`](https://github.com/mrjk/python-project-poetry-template/commit/7bcb3c0e23821f5a8090d66c6cd06e64c0598370))
* Simple bug ([`bdd1003`](https://github.com/mrjk/python-project-poetry-template/commit/bdd10035d782ec9ed4e385f519e3d8c0ba9ea2a2))
* Simple bug ([`f1024fd`](https://github.com/mrjk/python-project-poetry-template/commit/f1024fd694a3007902d85c1b7d6ba96ea9dbf149))
* Taskfile.yml ([`f098ddf`](https://github.com/mrjk/python-project-poetry-template/commit/f098ddf3e8b035a72d212fc774555e1c4354e3df))
* Tests ([`fd2cbe9`](https://github.com/mrjk/python-project-poetry-template/commit/fd2cbe97d57d178d0ee983fd30f550dbc81746b8))
* Tests ([`2b640f1`](https://github.com/mrjk/python-project-poetry-template/commit/2b640f18fe20fbf798be2f0536d7fdaa2d9ec813))
* Simple bug ([`e35985a`](https://github.com/mrjk/python-project-poetry-template/commit/e35985aa6660a0dbd169aed6b2c57138a06b7582))
* Simple bug ([`e689d05`](https://github.com/mrjk/python-project-poetry-template/commit/e689d05bb87d23eb3e60e3800d4e357390ebf1be))
* Simple bug ([`2d440d7`](https://github.com/mrjk/python-project-poetry-template/commit/2d440d730fe426dc5ad9f65e295d87afee4183f3))
* Simple bug ([`e827970`](https://github.com/mrjk/python-project-poetry-template/commit/e8279707127443fb3a7422e58fbc4e5bf55c6091))
* Simple bug ([`af3c439`](https://github.com/mrjk/python-project-poetry-template/commit/af3c4399bf7d9cfe899eb69b15961d168b773766))
* Simple bug ([`27c3efc`](https://github.com/mrjk/python-project-poetry-template/commit/27c3efc856310418b5581ac338928735b922e996))
* Simple bug ([`debaedb`](https://github.com/mrjk/python-project-poetry-template/commit/debaedb4e7ff8b53e252eaa5906d6f2ab8524d23))
* Simple bug ([`4032757`](https://github.com/mrjk/python-project-poetry-template/commit/4032757ddac8c4c41102818712df7fe4cb1ccc0e))
* Simple bug ([`65208f0`](https://github.com/mrjk/python-project-poetry-template/commit/65208f0bc7b89de082168da1f0572378b4542616))
* Simple bug ([`7a3a63b`](https://github.com/mrjk/python-project-poetry-template/commit/7a3a63bfb29f6f034a02fb29360a192c4b436171))
* Simple bug ([`5a5bbfc`](https://github.com/mrjk/python-project-poetry-template/commit/5a5bbfc1d7eb206f4204dfa681b243eae84c9029))
* Simple bug ([`a68988b`](https://github.com/mrjk/python-project-poetry-template/commit/a68988bc9738d5fb55bab28736fba12435f66f30))
* Simple bug ([`8617894`](https://github.com/mrjk/python-project-poetry-template/commit/861789417b4b9feba5981fbb3e4abff16f018616))
* Simple bug ([`268a40c`](https://github.com/mrjk/python-project-poetry-template/commit/268a40cc3e403a7f3b0edf139dcb468639011a5b))
* Simple bug ([`a41de80`](https://github.com/mrjk/python-project-poetry-template/commit/a41de809214a56b427422fcc3a13194d47fcdd3a))
* Simple bug ([`0f72b52`](https://github.com/mrjk/python-project-poetry-template/commit/0f72b52edbfb7e2ab64fe1e948df1d4cf31cfb6f))
* Simple bug ([`0f07db4`](https://github.com/mrjk/python-project-poetry-template/commit/0f07db451cf99b44f856db974a9b6dbac75cb51e))
* Simple bug ([`cff8f2f`](https://github.com/mrjk/python-project-poetry-template/commit/cff8f2fd1d33060b700dd2a69cf9177fc6029dc9))
* Simple bug ([`39ec953`](https://github.com/mrjk/python-project-poetry-template/commit/39ec953e2796b39c740b032d92910217452d190e))
* Simple bug ([`493d6bf`](https://github.com/mrjk/python-project-poetry-template/commit/493d6bf1259ef0c1107fab5b22ab88fcce96f1b9))
* Simple bug ([`50ba746`](https://github.com/mrjk/python-project-poetry-template/commit/50ba746a288c7c26675eec1cde7ec75e33848e90))
* Simple bug ([`e02fafa`](https://github.com/mrjk/python-project-poetry-template/commit/e02fafa0dcb7189c4d769395afc10882f033ea85))
* Simple bug ([`9eb7afb`](https://github.com/mrjk/python-project-poetry-template/commit/9eb7afbd4424989b8a11bece17d44443dbf150ca))
* Simple bug ([`5276664`](https://github.com/mrjk/python-project-poetry-template/commit/5276664f384f0145ab28d618c2a82d3763294b4f))
* Simple bug ([`22643a0`](https://github.com/mrjk/python-project-poetry-template/commit/22643a0161e852e73e9700ded4142e0001791276))
* Simple bug ([`d8775db`](https://github.com/mrjk/python-project-poetry-template/commit/d8775db45b43311abcc91cda4b162e9b4739ecc0))
* Simple bug ([`b389b45`](https://github.com/mrjk/python-project-poetry-template/commit/b389b45efa7913b6645136ecf63f855c0eb8ebbe))
* Simple bug ([`55e7131`](https://github.com/mrjk/python-project-poetry-template/commit/55e71318bf2c4d137456e899c0c2b13d67d06178))
* Simple bug ([`ada9df6`](https://github.com/mrjk/python-project-poetry-template/commit/ada9df6840e455bb937170c4baea812d0c49275b))
* Simple bug ([`b5e1ddb`](https://github.com/mrjk/python-project-poetry-template/commit/b5e1ddb1076c9b9ed06342db8361816c6438ec29))
* Simple bug ([`c551027`](https://github.com/mrjk/python-project-poetry-template/commit/c551027d35d17873934b4389137bf4e66beae9a7))
* Simple bug ([`a790daa`](https://github.com/mrjk/python-project-poetry-template/commit/a790daa44deab4a49c23952f26f57e76629cc7c9))
* Taskfile.yml ([`15bc3ee`](https://github.com/mrjk/python-project-poetry-template/commit/15bc3eed445020e22e465b5910b1ed874fa54d26))
* Simple bug ([`17055a6`](https://github.com/mrjk/python-project-poetry-template/commit/17055a630942f8f60a35fba5a0d167dcd64a054f))
* Bad version reporting for CLI ([`79258b2`](https://github.com/mrjk/python-project-poetry-template/commit/79258b240dd59adb2ffed80180097dc8cfd6fcc0))
* New patched version for python-semantic-release ([`03ec3a1`](https://github.com/mrjk/python-project-poetry-template/commit/03ec3a1c6101829f2ca68f13f05ae76854f98d70))
* **ci:** Add things ([`3e277cc`](https://github.com/mrjk/python-project-poetry-template/commit/3e277cc5d6c45bee3814d0c90c0563fc9e4bf268))
* **ci:** Add things ([`42ec4b6`](https://github.com/mrjk/python-project-poetry-template/commit/42ec4b64e305371b8ef1f426757d65891ac28df1))
* Missing .pre-commit-config.yaml file ([`329c044`](https://github.com/mrjk/python-project-poetry-template/commit/329c044b9e68cc81f96244aa758abc8d0744cb56))
* **ci:** Add things ([`e041038`](https://github.com/mrjk/python-project-poetry-template/commit/e041038fb3987ed1d03da46e8b167da6db0b95fb))
* **ci:** Add things ([`fdc507b`](https://github.com/mrjk/python-project-poetry-template/commit/fdc507b210b8a74a2c433cee5f3eb70b367b0f2e))
* **ci:** Add things ([`468fe0c`](https://github.com/mrjk/python-project-poetry-template/commit/468fe0cf4128ecfd827e49e331e87847f2530b67))
* **ci:** Add things ([`3fbdcc1`](https://github.com/mrjk/python-project-poetry-template/commit/3fbdcc1d75654e402a706a88415d1d1b3616e727))
* **ci:** Add things ([`a868925`](https://github.com/mrjk/python-project-poetry-template/commit/a868925bf95a3ec2e9a30f21beaecb27d7befd54))
* **ci:** Add things ([`8b5ecfc`](https://github.com/mrjk/python-project-poetry-template/commit/8b5ecfca45c4440cce4588e01fcc6e2741d0d0ca))
* **ci:** Add things ([`c2a0e4e`](https://github.com/mrjk/python-project-poetry-template/commit/c2a0e4e15fd5d1aa78e70edd2e6ab1df69e2659d))
* **ci:** Add things ([`6c871a9`](https://github.com/mrjk/python-project-poetry-template/commit/6c871a932bd42d48b7d350cedbfc810f1e67412a))
* **ci:** Add things ([`319e67b`](https://github.com/mrjk/python-project-poetry-template/commit/319e67bd2eaae473cf103d7d47d8e775d10a5b80))
* **ci:** Add things ([`4a9e9f2`](https://github.com/mrjk/python-project-poetry-template/commit/4a9e9f2cf29794f2c8f0779cf41a0be6d8383968))
* **ci:** Add things ([`0a17463`](https://github.com/mrjk/python-project-poetry-template/commit/0a174635c7894c53dedb08158efe107f6fe95e43))
* **ci:** Add things ([`f857592`](https://github.com/mrjk/python-project-poetry-template/commit/f857592669f175254fb02f9e71fc63324ed7c78c))
* **ci:** Add things ([`0e8f70e`](https://github.com/mrjk/python-project-poetry-template/commit/0e8f70e4e4aba88491b733881742183febffce68))
* **ci:** Add things ([`04ce9d0`](https://github.com/mrjk/python-project-poetry-template/commit/04ce9d0a0253590ff7608dc6e2f1352bcd46889e))
* **ci:** Add things ([`2157e7a`](https://github.com/mrjk/python-project-poetry-template/commit/2157e7af07f303b05aa80280108d7cf08f43d0be))
* New test ([`6a617c8`](https://github.com/mrjk/python-project-poetry-template/commit/6a617c8071a462154807e4407c385594cebee6e2))
* **ci:** Pre-commit config ([`c2f11c2`](https://github.com/mrjk/python-project-poetry-template/commit/c2f11c24c01679405ffaf41273b76d1247d9e079))
* TOTO readme ([`64b73b8`](https://github.com/mrjk/python-project-poetry-template/commit/64b73b88f6b035de7087b1b7b11307b8d1286cec))
* Pipelines ([`8041810`](https://github.com/mrjk/python-project-poetry-template/commit/804181071a3d540e3c74b163a8d15490e15615d6))
* Change 2 ([`6014474`](https://github.com/mrjk/python-project-poetry-template/commit/6014474517d27c36424c7f4cefd04d5ceeeb2701))
* Change 1 ([`39061d4`](https://github.com/mrjk/python-project-poetry-template/commit/39061d4577f69d6b9a0f2177947b872b76255b54))
* Change 0 ([`4eda7c0`](https://github.com/mrjk/python-project-poetry-template/commit/4eda7c03e0f97d20566cd4d8cc72bd9d300697bb))
* Change 2 ([`b9ee2fd`](https://github.com/mrjk/python-project-poetry-template/commit/b9ee2fdedbc7b628aa42ca8929a6c3ecd9397ab5))
* Change 1 ([`21739d0`](https://github.com/mrjk/python-project-poetry-template/commit/21739d0635dcaa2709628f1589d4756f1bf47c25))
* Change 0 ([`835953a`](https://github.com/mrjk/python-project-poetry-template/commit/835953a68d0c80f9042c8f6ac08b93241e0473be))
* Change 2 ([`85ab846`](https://github.com/mrjk/python-project-poetry-template/commit/85ab846e13f369f1ee66a49a1e74a0136ef08dff))
* Change 1 ([`8fd48bc`](https://github.com/mrjk/python-project-poetry-template/commit/8fd48bce67ddb278dd61f90ed87ade70019e0a52))
* Change 0 ([`dfd779a`](https://github.com/mrjk/python-project-poetry-template/commit/dfd779a4a0a3b0ce5b5dca814db854706e6ac0f7))
* Prj settings ([`ec91f83`](https://github.com/mrjk/python-project-poetry-template/commit/ec91f83dbbe0d9590b1acbe6eb547bceaef0de7a))
* Change 2 ([`11a7994`](https://github.com/mrjk/python-project-poetry-template/commit/11a799474ba5956a6aa0505faf2a826e26985183))
* Change 2 ([`4e2fb30`](https://github.com/mrjk/python-project-poetry-template/commit/4e2fb30670bd607b3e21458164994c0e34125aec))
* Change 2 ([`1e2f642`](https://github.com/mrjk/python-project-poetry-template/commit/1e2f642f7abcedca6887d360b4db8dd08a2311ab))
* Change 2 ([`8b7ac23`](https://github.com/mrjk/python-project-poetry-template/commit/8b7ac230033363dbeebc7c37df005bcceb01cbc0))
* Change 2 ([`ea1b2f3`](https://github.com/mrjk/python-project-poetry-template/commit/ea1b2f3851c63d68b3cd87cffae22231afe6cc31))
* Change 2 ([`263ebc3`](https://github.com/mrjk/python-project-poetry-template/commit/263ebc3c59a15d08e16feea5e1704c7978632f03))
* Change 2 ([`acc3764`](https://github.com/mrjk/python-project-poetry-template/commit/acc376427b8cac9c2aa5d3b89a37e876c6c6cb4e))
* Change 2 ([`fb45587`](https://github.com/mrjk/python-project-poetry-template/commit/fb45587f0699a75097bb56e9f25a2c0d91c4a66d))
* Change 2 ([`341a0cc`](https://github.com/mrjk/python-project-poetry-template/commit/341a0cc562ce01083d88bcbcf2a7b362fab6c580))
* Change 2 ([`fd4940c`](https://github.com/mrjk/python-project-poetry-template/commit/fd4940ca91cec4da6a25b88af46a12d171ce3961))
* Change 2 ([`d9b2632`](https://github.com/mrjk/python-project-poetry-template/commit/d9b26327fc1764df1dcfcadd6ab928ef0928342c))
* Change 2 ([`b4225c5`](https://github.com/mrjk/python-project-poetry-template/commit/b4225c554f664a79a7848ac1a17928dcff28c152))
* Change 2 ([`42f776c`](https://github.com/mrjk/python-project-poetry-template/commit/42f776c5ca4f22662d3b573f2b7cde7100c11584))
* Project ([`93d7d05`](https://github.com/mrjk/python-project-poetry-template/commit/93d7d0515c2ba1c5578577939ff1d3b18ef7e8c7))
* Change 2 ([`27d24fd`](https://github.com/mrjk/python-project-poetry-template/commit/27d24fdc0b3edcb09be0ebc44317199d2946a78c))
* Change 2 ([`f26c124`](https://github.com/mrjk/python-project-poetry-template/commit/f26c124944d14a10c5a9adad7698ae4db3801011))
* Project ([`98987d6`](https://github.com/mrjk/python-project-poetry-template/commit/98987d665453d9b0b71090fa5c39b3df3552e2d4))
* Prj ([`3f17a90`](https://github.com/mrjk/python-project-poetry-template/commit/3f17a90ec5ec5e3b67a63008558b08d774a9e392))
* Change 2 ([`6ff8884`](https://github.com/mrjk/python-project-poetry-template/commit/6ff88849bbeca167a46c9514dd89c340143fca57))
* Change 2 ([`c5ca600`](https://github.com/mrjk/python-project-poetry-template/commit/c5ca600c53c6fa7d3407666dfa1182fa69742ee3))
* Change 2 ([`6877e36`](https://github.com/mrjk/python-project-poetry-template/commit/6877e368598ec3ab5d09d8eff4ff5660417245d7))
* Change 2 ([`bbe5473`](https://github.com/mrjk/python-project-poetry-template/commit/bbe54730a64f7c7b51a6a6ed3b08dc95c29fc9b4))
* Change 2 ([`e5408ef`](https://github.com/mrjk/python-project-poetry-template/commit/e5408efc470c84f4c4f6443601dbfd84e3fac86f))
* Change 2 ([`ca9d896`](https://github.com/mrjk/python-project-poetry-template/commit/ca9d8965580078b72c2044ddc4032528cf8e4c6a))
* Change 2 ([`b231f66`](https://github.com/mrjk/python-project-poetry-template/commit/b231f665d22dbeca785772c694bc30c51ca4af36))
* Project ([`d3ebef9`](https://github.com/mrjk/python-project-poetry-template/commit/d3ebef900026e8474ee7fed26438d44f0c420bc7))
* Project ([`325298c`](https://github.com/mrjk/python-project-poetry-template/commit/325298c3e59af46ee4fa4b7001e6637133efa1eb))
* Project ([`e5ce727`](https://github.com/mrjk/python-project-poetry-template/commit/e5ce7271afd36c7e8d1d49910bc314af85d355cf))
* Change 2 ([`552cfbd`](https://github.com/mrjk/python-project-poetry-template/commit/552cfbdc16abadb7c829b5b52d1630a58bcaf0e2))
* Project ([`cb8976e`](https://github.com/mrjk/python-project-poetry-template/commit/cb8976ec2052d617a6aa0e959111a8fe496f9278))
* Change 2 ([`639a8ac`](https://github.com/mrjk/python-project-poetry-template/commit/639a8ac2b3a009edaba0639ba6e1abbd100fdaf0))
* Change 2 ([`65387ff`](https://github.com/mrjk/python-project-poetry-template/commit/65387ffbb2fd32a597bbc479de80548676e23a0b))
* Change 2 ([`b3c202d`](https://github.com/mrjk/python-project-poetry-template/commit/b3c202d6eeb277eda5c0ba1ee9dc767826f835e4))
* Change 2 ([`68b6184`](https://github.com/mrjk/python-project-poetry-template/commit/68b61843525e40462653d6e0ff09d43aded7cc2e))
* Project ([`c9e13b3`](https://github.com/mrjk/python-project-poetry-template/commit/c9e13b37b0bf7610aba3ee27aca21ddd8c522caf))
* Change 2 ([`53c1e81`](https://github.com/mrjk/python-project-poetry-template/commit/53c1e81636bd03421f931ff2724ba3a6811e0a63))
* Change 2 ([`92da6d7`](https://github.com/mrjk/python-project-poetry-template/commit/92da6d7bece0bb78eb11b7b1453af57ea8f6ce7c))

### Documentation
* Update README ([`5e51784`](https://github.com/mrjk/python-project-poetry-template/commit/5e517849379d5983970391c23428d86918c852a9))
* Add support for gh pages ([`329e1e2`](https://github.com/mrjk/python-project-poetry-template/commit/329e1e2fb10b97e044debc13e7b88dde85190a3e))
* Documentation release on gh ([`d3737ae`](https://github.com/mrjk/python-project-poetry-template/commit/d3737ae7addd2cd4fd59c1913f537b3ae97230ca))
* Update docs ([`aa829de`](https://github.com/mrjk/python-project-poetry-template/commit/aa829de48dca81baaf082a0dc590940b10bc9846))
* Append mainteners and contrib guidelines ([`01f18df`](https://github.com/mrjk/python-project-poetry-template/commit/01f18dfe5e214f0979f31be5367a30393591b6f3))
* Update doc ([`6fa37c1`](https://github.com/mrjk/python-project-poetry-template/commit/6fa37c1f93810a071ef2d7dbe19672e33a9fdd6e))
* **docker:** Add docker-compose support ([`b629afb`](https://github.com/mrjk/python-project-poetry-template/commit/b629afb43fdbcf0924cc65c332c93c988474f326))
* **scripts:** Taskdev.yml support ([`8701138`](https://github.com/mrjk/python-project-poetry-template/commit/87011383aec34fc4525e47cde28af69fa8c64b33))
* **user_doc:** Add support for html documentation ([`33686dc`](https://github.com/mrjk/python-project-poetry-template/commit/33686dc1c7b0468865348722a406299e76d346b8))

## v0.10.9-beta.10 (2022-11-16)


## v0.10.9-beta.9 (2022-11-16)
### Fix
* Simple bugfix 92 ([`326e83c`](https://github.com/mrjk/python-project-poetry-template/commit/326e83c2a7cbca167ec897225a78b2c995bbf218))
* Simple bugfix 86 ([`48dc6d9`](https://github.com/mrjk/python-project-poetry-template/commit/48dc6d9e9ce5f68bec70ba3cf78c4fcf294f8482))
* Simple bugfix 54 ([`e1d6a79`](https://github.com/mrjk/python-project-poetry-template/commit/e1d6a79d121d07e81b107a489e28c53af46a3eaf))
* Simple bugfix 1 ([`8fe03dd`](https://github.com/mrjk/python-project-poetry-template/commit/8fe03ddbc857e789e4e890995cad1405e6713a25))

## v0.10.9-beta.8 (2022-11-16)
### Fix
* WIP release ([`b034ffb`](https://github.com/mrjk/python-project-poetry-template/commit/b034ffbfec19c6b5059c931fad369a03788488fc))

## v0.10.9-beta.7 (2022-11-16)
### Fix
* Simple bugfix 145sad ([`aa68761`](https://github.com/mrjk/python-project-poetry-template/commit/aa687612cab7a3180373ba394513aa75297f06b8))
* Simple bugfix 145sad ([`0be2be4`](https://github.com/mrjk/python-project-poetry-template/commit/0be2be480a2fccaf17ada031ed5ac129761462a4))

## v0.10.9-beta.6 (2022-11-16)
### Fix
* Simple bugfix 145sad ([`bb8c1a8`](https://github.com/mrjk/python-project-poetry-template/commit/bb8c1a87aab4831fae719534a6954b181c3ca37b))
* Simple bugfix 145sad ([`8887184`](https://github.com/mrjk/python-project-poetry-template/commit/88871848974523563a9b77768429aa2b2e4be2e9))

## v0.10.9-beta.5 (2022-11-16)
### Fix
* Disable github release ([`f842c22`](https://github.com/mrjk/python-project-poetry-template/commit/f842c22fd8032418c959680761aeac7c27968309))
* Disable github release ([`3686e8f`](https://github.com/mrjk/python-project-poetry-template/commit/3686e8f2ad24143e7a418a8d6c53b4e135325e38))

## v0.10.9-beta.4 (2022-11-16)
### Fix
* Disable github release ([`69b5f5f`](https://github.com/mrjk/python-project-poetry-template/commit/69b5f5f980b49e720c6ed81b8608f85f88fff9ba))
* Disable github release ([`8c2a5d2`](https://github.com/mrjk/python-project-poetry-template/commit/8c2a5d2a688d1d3c88d5ba488b7b38c3eff73622))
* Ci ([`acd7d38`](https://github.com/mrjk/python-project-poetry-template/commit/acd7d38efec6f5f6c83292a8cd4a98e7295a7dc1))

## v0.10.9-beta.3 (2022-11-16)
### Fix
* Ci ([`e847ce2`](https://github.com/mrjk/python-project-poetry-template/commit/e847ce2860797fc1fe8d4a38d60eb03760f0c061))

## v0.10.9-beta.2 (2022-11-16)
### Fix
* Ci ([`95cd6f3`](https://github.com/mrjk/python-project-poetry-template/commit/95cd6f33928eaea6d6d3be375a72194afcfdf118))

## v0.10.9-beta.1 (2022-11-16)
### Fix
* Ci ([`455753e`](https://github.com/mrjk/python-project-poetry-template/commit/455753e0003c0f4134b4369f38ea1949e7b074b2))
* Ci ([`906e835`](https://github.com/mrjk/python-project-poetry-template/commit/906e8350bdfdbbc1e80ffa51651f8e9af9696045))

## v0.10.8 (2022-11-16)
### Fix
* Simple bugfix 145sad ([`8f30070`](https://github.com/mrjk/python-project-poetry-template/commit/8f300706d824fb30da7e0c44d57f062a8758e44c))
* Simple bugfix 145 ([`af0496a`](https://github.com/mrjk/python-project-poetry-template/commit/af0496ae17830f014caa09eedd38f65a169c253e))
* Simple bugfix 11 ([`d716524`](https://github.com/mrjk/python-project-poetry-template/commit/d716524a8dfd8004ab1740814c1c3211ab8e9994))
* Simple bugfix 10 ([`93c284e`](https://github.com/mrjk/python-project-poetry-template/commit/93c284e39e9da0c3e40a3f8a1c876f3ab3160732))

## v0.10.7 (2022-11-16)
### Fix
* Simple bugfix3 ([`c374ffe`](https://github.com/mrjk/python-project-poetry-template/commit/c374ffe7b79f5864568c6f2610137d2fe0c6a4e2))
* Simple bugfix3 ([`76cae9b`](https://github.com/mrjk/python-project-poetry-template/commit/76cae9b85aa64b7a655e4cf87eee640783173840))
* Simple bugfix3 ([`05a3741`](https://github.com/mrjk/python-project-poetry-template/commit/05a374165235515c42835bbad1a7afca6a16565b))
* Simple bugfix3 ([`d34655f`](https://github.com/mrjk/python-project-poetry-template/commit/d34655f7f66513ef5297d9c97c9a9640f9c36644))

## v0.10.6 (2022-11-16)
### Fix
* Simple bugfix3 ([`92ee020`](https://github.com/mrjk/python-project-poetry-template/commit/92ee020fddf94abf391115b28916113f9774b528))
* Simple bugfix2 ([`dba214a`](https://github.com/mrjk/python-project-poetry-template/commit/dba214ae4b90ee68e33f4a1f748022cdff2a8dc8))
* Simple bugfix1 ([`ce0a5a2`](https://github.com/mrjk/python-project-poetry-template/commit/ce0a5a23422a49c4a6b4cdc97f56917e370280ed))

## v0.10.5 (2022-11-16)
### Fix
* Simple bugfix1 ([`1cc83c4`](https://github.com/mrjk/python-project-poetry-template/commit/1cc83c450fd7af2d738ea52d6928f43a66d6566f))
* Simple bugfix2 ([`22407eb`](https://github.com/mrjk/python-project-poetry-template/commit/22407eb444f845e5a6485bd7d1b4a90e24d21c32))
* Simple bugfix3 ([`d071adb`](https://github.com/mrjk/python-project-poetry-template/commit/d071adba52efb1066cfb7361f696487c8748be8e))

## v0.10.4 (2022-11-16)
### Fix
* Ci ([`badaa60`](https://github.com/mrjk/python-project-poetry-template/commit/badaa60635ea9d8d44941c79902b8410339fc6f3))

## v0.10.3 (2022-11-16)
### Fix
* GH workflow ([`e7ce38d`](https://github.com/mrjk/python-project-poetry-template/commit/e7ce38d36abd65d5646fb01574c52b20de96c5d0))
* GH workflow ([`275c598`](https://github.com/mrjk/python-project-poetry-template/commit/275c59815e28f181478353e43be712f123b5d8f9))
* GH workflow ([`5a12c01`](https://github.com/mrjk/python-project-poetry-template/commit/5a12c01b606589b35cf894f1735002a5c7559c4c))
* Taskfile ([`cc8f970`](https://github.com/mrjk/python-project-poetry-template/commit/cc8f9704ebb4a5c5e5ba1a778b556a5e2e462ebb))
* Taskfile release process ([`6bdf1d3`](https://github.com/mrjk/python-project-poetry-template/commit/6bdf1d39747a9dd80d452c5ddebf4bc9df2bc1d2))
* Simple bugfix3 ([`9b0b97e`](https://github.com/mrjk/python-project-poetry-template/commit/9b0b97e8de6cf05778faacd554841cda635d6bad))
* GH workflow ([`9b89070`](https://github.com/mrjk/python-project-poetry-template/commit/9b8907015abd3d92a2d02d422ea0fca4db0cdcb3))
* GH workflow ([`0a4673d`](https://github.com/mrjk/python-project-poetry-template/commit/0a4673d42af6835ad49b882e32f6dad84dc6a36a))
* GH workflow ([`d3debe2`](https://github.com/mrjk/python-project-poetry-template/commit/d3debe2ad6168a8cd9c4715f92342555d3bf1271))
* GH workflow ([`b7bfecb`](https://github.com/mrjk/python-project-poetry-template/commit/b7bfecba46e41c29995fd25bcf64ec4438af3d38))
* GH workflow ([`db161ec`](https://github.com/mrjk/python-project-poetry-template/commit/db161ecefaf3476886ae99e769ec8682b9a86617))
* GH workflow ([`070fdd9`](https://github.com/mrjk/python-project-poetry-template/commit/070fdd900ab9156c563095ac271247a8ab4688df))
* Simple bugfix3 ([`1458569`](https://github.com/mrjk/python-project-poetry-template/commit/1458569fa788dc33bb348ef92bdb90f7f1ba029a))
* Simple bugfix2 ([`f6169cd`](https://github.com/mrjk/python-project-poetry-template/commit/f6169cd251d697f700d2e71a43d6d08c3954edf5))
* Simple bugfix1 ([`e83b262`](https://github.com/mrjk/python-project-poetry-template/commit/e83b2628392d631fd82faf0d9eb7755b3eb96d52))

## v0.10.2 (2022-11-16)
### Fix
* Taskfile ([`a270e15`](https://github.com/mrjk/python-project-poetry-template/commit/a270e15ab2228f996c063418c74d42510d736123))
* GH workflow ([`0f96138`](https://github.com/mrjk/python-project-poetry-template/commit/0f9613813a996958fb31480688ac130e1e3e2896))

## v0.10.1 (2022-11-16)
### Fix
* GH workflow ([`d6b74ad`](https://github.com/mrjk/python-project-poetry-template/commit/d6b74ad00df4006035337919ed1eb8f19ed09198))
* GH workflow ([`b54959c`](https://github.com/mrjk/python-project-poetry-template/commit/b54959c6879f317ef4a4a9285171114c5fb962b9))
* GH workflow ([`53cf1ca`](https://github.com/mrjk/python-project-poetry-template/commit/53cf1ca512f35717b8cc4f7f791a2f36c1f372ce))
* GH workflow ([`0333f61`](https://github.com/mrjk/python-project-poetry-template/commit/0333f611b8b29723839934696a827f5dc8317bd3))
* GH workflow ([`5bb16bf`](https://github.com/mrjk/python-project-poetry-template/commit/5bb16bf11a9c1d8675887ed2659ebcd9b4b93ba4))
* GH workflow ([`0137c74`](https://github.com/mrjk/python-project-poetry-template/commit/0137c741317714ddb509cd5f944fd25d985e599c))
* GH workflow ([`4a1b5eb`](https://github.com/mrjk/python-project-poetry-template/commit/4a1b5eb24f666dd2681da51029340e54f03a4568))
* GH workflow ([`95d42f6`](https://github.com/mrjk/python-project-poetry-template/commit/95d42f60d8618d826311efe311648c3fe14373d8))
* GH workflow ([`6e1f8c8`](https://github.com/mrjk/python-project-poetry-template/commit/6e1f8c845c00955e523312daa12dd6e4b2bfe94c))
* GH workflow ([`ccb8324`](https://github.com/mrjk/python-project-poetry-template/commit/ccb83240de22699787561ace3ac9b7b6178eeb46))
* GH workflow ([`f7d72e7`](https://github.com/mrjk/python-project-poetry-template/commit/f7d72e7fe37e8c94187c393ae6238e31d86842cd))
* GH workflow ([`ae715eb`](https://github.com/mrjk/python-project-poetry-template/commit/ae715ebc9e9700e7d7f5f3be098dcc5f1470cfa5))
* GH workflow ([`09519a1`](https://github.com/mrjk/python-project-poetry-template/commit/09519a147bdce2e7aabdfc11dad99df193eb4bd7))
* GH workflow ([`3ca1ea4`](https://github.com/mrjk/python-project-poetry-template/commit/3ca1ea42e3a2a08a922965ea6c59d73ba6207df1))
* GH workflow ([`eabc0b0`](https://github.com/mrjk/python-project-poetry-template/commit/eabc0b059edc7575d95b8cb149dead1acf8b695a))
* GH workflow ([`8edbfe7`](https://github.com/mrjk/python-project-poetry-template/commit/8edbfe770255a4a91a46cf69338737f8411c988f))
* GH workflow ([`776ac16`](https://github.com/mrjk/python-project-poetry-template/commit/776ac166b9663826752f8b9e98d1026936fd6955))
* GH workflow ([`3f01e7c`](https://github.com/mrjk/python-project-poetry-template/commit/3f01e7c971cb7135f1fddce287d8f72751483b23))
* GH workflow ([`7ba7703`](https://github.com/mrjk/python-project-poetry-template/commit/7ba770308e6c2dc67ee4be75eb598288ea6ee8dc))
* GH workflow ([`def11fc`](https://github.com/mrjk/python-project-poetry-template/commit/def11fc372ba61c676f34ebe3e95a1a749f42da4))
* GH workflow ([`f463c22`](https://github.com/mrjk/python-project-poetry-template/commit/f463c22ec36f4041fa3ff3bdb54d4778c777c5d2))
* GH workflow ([`7c96545`](https://github.com/mrjk/python-project-poetry-template/commit/7c96545ac9e5ff6b916c79c925daa7cbbb75278d))

## v0.10.0 (2022-11-16)
### Feature
* Complete the CI scripts ([`94eb0cf`](https://github.com/mrjk/python-project-poetry-template/commit/94eb0cfe485f775cd63bbe595b37cd88545d4941))

### Fix
* Missing .gitignore ([`59de782`](https://github.com/mrjk/python-project-poetry-template/commit/59de7829c18986bfdc783b2b3446d7d817270b4d))

### Documentation
* Update README ([`5e51784`](https://github.com/mrjk/python-project-poetry-template/commit/5e517849379d5983970391c23428d86918c852a9))

## v0.9.0 (2022-11-16)
### Fix
* Little errors ([`2eaead9`](https://github.com/mrjk/python-project-poetry-template/commit/2eaead9ee35b77ca182f30867bb3ed26e37fe25f))

## v0.9.0-beta.20 (2022-11-16)
### Fix
* Extra VERSION_NOTES.md.md file ([`39e9330`](https://github.com/mrjk/python-project-poetry-template/commit/39e93304740f6e3a908a505f6dfbb15e361bc377))

## v0.9.0-beta.19 (2022-11-16)
### Fix
* Simple bug ([`211f0b8`](https://github.com/mrjk/python-project-poetry-template/commit/211f0b82cdc01b3ad5e9c59a5d0ee0b1a62bd34e))
* Simple bug ([`f742d6d`](https://github.com/mrjk/python-project-poetry-template/commit/f742d6d529ef663f0b2f784dc02d0adda4c0a7eb))
* Simple bug ([`4304b89`](https://github.com/mrjk/python-project-poetry-template/commit/4304b89dd19b5639adf1a2efb2e76e2b2a0129df))
* Little errors ([`df3a4e2`](https://github.com/mrjk/python-project-poetry-template/commit/df3a4e28d309f063d19e4fd303fd411dc437c7dd))

## v0.9.0-beta.18 (2022-11-16)
### Fix
* Remove old LAST_CHANGES.md ([`498600a`](https://github.com/mrjk/python-project-poetry-template/commit/498600ae142324b7bd2684ab322929fbab9a2915))

## v0.9.0-beta.17 (2022-11-16)
### Fix
* Little errors ([`4aa4ccc`](https://github.com/mrjk/python-project-poetry-template/commit/4aa4ccc9b55b90591a1c2f4587a42e8fc32d5285))

## v0.9.0-beta.16 (2022-11-16)
### Fix
* Little errors ([`f2b0511`](https://github.com/mrjk/python-project-poetry-template/commit/f2b0511ce37c0ba8783de2627a6d76ba37a55273))

## v0.9.0-beta.15 (2022-11-16)
### Fix
* Little errors ([`8893dc2`](https://github.com/mrjk/python-project-poetry-template/commit/8893dc2fc8e89fc12df9620c3d9d3d316f802fee))
* Missing RELEASE.md ([`8efd20e`](https://github.com/mrjk/python-project-poetry-template/commit/8efd20ebfa603068c457d42e0de7f1f769c61da5))

## v0.9.0-beta.14 (2022-11-16)
### Fix
* Missing RELEASE.md ([`2d4079c`](https://github.com/mrjk/python-project-poetry-template/commit/2d4079cf989bcb1611c96ae6e9ce9b8a2417098f))

## v0.9.0-beta.13 (2022-11-16)
### Fix
* Ci ([`5662bb0`](https://github.com/mrjk/python-project-poetry-template/commit/5662bb0d161b9a34abc30d14025b280800cb7309))

## v0.9.0-beta.12 (2022-11-16)
### Fix
* Ci ([`069facf`](https://github.com/mrjk/python-project-poetry-template/commit/069facfdb05f894e4552cd23dc12ef1b91a70725))

## v0.9.0-beta.11 (2022-11-16)
### Fix
* Ci ([`dea286a`](https://github.com/mrjk/python-project-poetry-template/commit/dea286a65ec6eeca0cf9a373f09b2de8acc65162))

## v0.9.0-beta.10 (2022-11-16)
### Fix
* Ci ([`50015ae`](https://github.com/mrjk/python-project-poetry-template/commit/50015aebd641b1dc1d618cc7f94b90a70fd3ab15))

## v0.9.0-beta.9 (2022-11-16)
### Fix
* Simple bug ([`299395c`](https://github.com/mrjk/python-project-poetry-template/commit/299395c6cb7b2a7a393b8923a1f087894b12eeb1))
* Simple bug ([`8ea91fc`](https://github.com/mrjk/python-project-poetry-template/commit/8ea91fc7bc67b704efc7ee683ced8f9a23118d47))

## v0.9.0-beta.8 (2022-11-16)
### Fix
* Ci ([`6fe1690`](https://github.com/mrjk/python-project-poetry-template/commit/6fe169096ffc635312d81672284ee2ef64721968))

## v0.9.0-beta.7 (2022-11-16)
### Fix
* Ci ([`65a86d6`](https://github.com/mrjk/python-project-poetry-template/commit/65a86d6ba4339e74beb8d7c764cbaeb98eeae168))

## v0.9.0-beta.6 (2022-11-16)
### Fix
* Ci ([`2c70f60`](https://github.com/mrjk/python-project-poetry-template/commit/2c70f607617bab5b735d0bf7b61b62da5aa19f66))

## v0.9.0-beta.5 (2022-11-16)
### Fix
* Ci ([`c48b089`](https://github.com/mrjk/python-project-poetry-template/commit/c48b089fb7bf492d628ed98aeeda9a98abb4eb0b))

## v0.9.0-beta.4 (2022-11-16)
### Fix
* Ci ([`60eeb18`](https://github.com/mrjk/python-project-poetry-template/commit/60eeb184a6e18e9297951e7d83f8866cba7eaf16))

## v0.9.0-beta.3 (2022-11-16)
### Fix
* RELEASES files ([`3aacc7f`](https://github.com/mrjk/python-project-poetry-template/commit/3aacc7f12ee43830e4254ffeb47ef252be3c462e))

## v0.9.0-beta.2 (2022-11-16)
### Fix
* RELEASE.md location ([`4909fe5`](https://github.com/mrjk/python-project-poetry-template/commit/4909fe5a09f1a1fd24ba04418a1ab245cf0966dc))

## v0.9.0-beta.1 (2022-11-16)
### Feature
* Update code ([`b327f73`](https://github.com/mrjk/python-project-poetry-template/commit/b327f739e347a1f49ac5c15039a796b5fa43052f))

### Fix
* Ci ([`c2f4264`](https://github.com/mrjk/python-project-poetry-template/commit/c2f4264172b6b5ba4aa07f077720f4f2c33a3d06))
* Simple bug ([`8db12c5`](https://github.com/mrjk/python-project-poetry-template/commit/8db12c59ca4aa280501e47ddf6be2709e02874ba))
* Simple bug ([`635195b`](https://github.com/mrjk/python-project-poetry-template/commit/635195beed0d842c6ac7472fabc0a9188231471b))
* Simple bug ([`4ce61c2`](https://github.com/mrjk/python-project-poetry-template/commit/4ce61c274d10e9e751f5cbb72c43457bcf48b8b3))

## v0.8.1-beta.5 (2022-11-16)
### Fix
* Missing REALEASE.md ([`f76cd3a`](https://github.com/mrjk/python-project-poetry-template/commit/f76cd3ae070dfe4c214940fa5944073a75c394fa))

## v0.8.1-beta.4 (2022-11-16)
### Fix
* Simple bug ([`1394e62`](https://github.com/mrjk/python-project-poetry-template/commit/1394e62e2163ee1c14864e9139a3c0a9cf75890f))
* Simple bug ([`6c575ee`](https://github.com/mrjk/python-project-poetry-template/commit/6c575eeabba36ca82b235cf0e873c18efdeccce1))
* Simple bug ([`b3b8e09`](https://github.com/mrjk/python-project-poetry-template/commit/b3b8e0941f0052fc0c1b573b63fc1c8b02ee658a))

## v0.8.1-beta.3 (2022-11-16)
### Fix
* Simple bug ([`5f37952`](https://github.com/mrjk/python-project-poetry-template/commit/5f37952c5570babf33b8f62fe33ac919cac1b658))
* Simple bug ([`f809a87`](https://github.com/mrjk/python-project-poetry-template/commit/f809a873e90acdc8cdc19664467564cb074adde6))
* Simple bug ([`2fae86c`](https://github.com/mrjk/python-project-poetry-template/commit/2fae86c1fc3c30a2a3d18072b48cecc8f8662f69))

## v0.8.1-beta.2 (2022-11-16)
### Fix
* Simple bug ([`13f20ed`](https://github.com/mrjk/python-project-poetry-template/commit/13f20ede4725a980c41de6623664a70567f5bf8e))
* Simple bug ([`c02164d`](https://github.com/mrjk/python-project-poetry-template/commit/c02164d0eec4b1bf1766cacee65db7dc33141241))
* Simple bug ([`284272b`](https://github.com/mrjk/python-project-poetry-template/commit/284272b202ffc746531bb6f9b12e94bcde0c8354))

## v0.8.1-beta.1 (2022-11-16)
### Fix
* Dist cleaning ([`eaf0dec`](https://github.com/mrjk/python-project-poetry-template/commit/eaf0dec0929119980c151b96f607ed3ef87a96aa))

## v0.8.0 (2022-11-16)
### Fix
* Simple bug ([`9de7690`](https://github.com/mrjk/python-project-poetry-template/commit/9de7690c03b351e59c807902beff576fd1fea710))
* Simple bug ([`35b5747`](https://github.com/mrjk/python-project-poetry-template/commit/35b57474352bb085c592c461c34ea898818145dc))
* Simple bug ([`ec9f71d`](https://github.com/mrjk/python-project-poetry-template/commit/ec9f71d3235a713da2b271308e25165d0c9a39b7))

## v0.8.0-beta.3 (2022-11-16)
### Fix
* Simple bug ([`7ffd970`](https://github.com/mrjk/python-project-poetry-template/commit/7ffd970161b465cb1d48f11e0e6d614aeeb40fe2))
* Simple bug ([`034206a`](https://github.com/mrjk/python-project-poetry-template/commit/034206a1b660d467409828537e1a4a86e2c176db))
* Simple bug ([`e5ae652`](https://github.com/mrjk/python-project-poetry-template/commit/e5ae652e4206a8de0bcbbd3980b5e8ce2ad021d2))

## v0.8.0-beta.2 (2022-11-16)


## v0.8.0-beta.1 (2022-11-16)
### Feature
* New feat ([`b4578e4`](https://github.com/mrjk/python-project-poetry-template/commit/b4578e4b170618e72534397da61e18f81790cb0d))
* New feat ([`c714a1c`](https://github.com/mrjk/python-project-poetry-template/commit/c714a1c48ba2c9ecb7bdd88b0c73f171334c7904))
* New feat ([`3e0b959`](https://github.com/mrjk/python-project-poetry-template/commit/3e0b9591f5a8019fd86d7939bf5bbc663633791d))

### Fix
* Simple bug ([`accd9ea`](https://github.com/mrjk/python-project-poetry-template/commit/accd9ea0ea0e3180c27c974e67552edfec02704f))
* Simple bug ([`1876550`](https://github.com/mrjk/python-project-poetry-template/commit/1876550e312ab5a40243d8c032dc86aaa9e19303))
* Simple bug ([`78440d7`](https://github.com/mrjk/python-project-poetry-template/commit/78440d78117415a29b73a0aff3715910cf865e9c))
* Simple bug ([`7bcb3c0`](https://github.com/mrjk/python-project-poetry-template/commit/7bcb3c0e23821f5a8090d66c6cd06e64c0598370))
* Simple bug ([`bdd1003`](https://github.com/mrjk/python-project-poetry-template/commit/bdd10035d782ec9ed4e385f519e3d8c0ba9ea2a2))
* Simple bug ([`f1024fd`](https://github.com/mrjk/python-project-poetry-template/commit/f1024fd694a3007902d85c1b7d6ba96ea9dbf149))

## v0.7.0 (2022-11-16)


## v0.7.0-beta.3 (2022-11-16)
### Fix
* Taskfile.yml ([`f098ddf`](https://github.com/mrjk/python-project-poetry-template/commit/f098ddf3e8b035a72d212fc774555e1c4354e3df))

## v0.7.0-beta.2 (2022-11-16)
### Feature
* Script to schow version ([`1380a82`](https://github.com/mrjk/python-project-poetry-template/commit/1380a82ab3ffdf12cae1fd41a119aa411090c028))

### Fix
* Tests ([`fd2cbe9`](https://github.com/mrjk/python-project-poetry-template/commit/fd2cbe97d57d178d0ee983fd30f550dbc81746b8))

## v0.7.0-beta.1 (2022-11-16)
### Feature
* New feat ([`bcd3cf5`](https://github.com/mrjk/python-project-poetry-template/commit/bcd3cf592b119145dd18516aeeb967a1c6f028e3))
* New feat ([`b12c159`](https://github.com/mrjk/python-project-poetry-template/commit/b12c159d32cbd6960cb14a6d4aa3f644b5742c8a))
* New feat ([`5ae395c`](https://github.com/mrjk/python-project-poetry-template/commit/5ae395c04a600c45991c1b803454f518f5507911))

## v0.6.3-beta.2 (2022-11-16)
### Fix
* Tests ([`2b640f1`](https://github.com/mrjk/python-project-poetry-template/commit/2b640f18fe20fbf798be2f0536d7fdaa2d9ec813))
* Simple bug ([`e35985a`](https://github.com/mrjk/python-project-poetry-template/commit/e35985aa6660a0dbd169aed6b2c57138a06b7582))
* Simple bug ([`e689d05`](https://github.com/mrjk/python-project-poetry-template/commit/e689d05bb87d23eb3e60e3800d4e357390ebf1be))
* Simple bug ([`2d440d7`](https://github.com/mrjk/python-project-poetry-template/commit/2d440d730fe426dc5ad9f65e295d87afee4183f3))

## v0.6.3-beta.1 (2022-11-16)


## v0.6.2 (2022-11-16)
### Fix
* Simple bug ([`e827970`](https://github.com/mrjk/python-project-poetry-template/commit/e8279707127443fb3a7422e58fbc4e5bf55c6091))
* Simple bug ([`af3c439`](https://github.com/mrjk/python-project-poetry-template/commit/af3c4399bf7d9cfe899eb69b15961d168b773766))
* Simple bug ([`27c3efc`](https://github.com/mrjk/python-project-poetry-template/commit/27c3efc856310418b5581ac338928735b922e996))

## v0.6.1 (2022-11-16)
### Fix
* Simple bug ([`debaedb`](https://github.com/mrjk/python-project-poetry-template/commit/debaedb4e7ff8b53e252eaa5906d6f2ab8524d23))
* Simple bug ([`4032757`](https://github.com/mrjk/python-project-poetry-template/commit/4032757ddac8c4c41102818712df7fe4cb1ccc0e))
* Simple bug ([`65208f0`](https://github.com/mrjk/python-project-poetry-template/commit/65208f0bc7b89de082168da1f0572378b4542616))

## v0.6.0 (2022-11-16)


## v0.6.0-beta.2 (2022-11-16)
### Feature
* New feat ([`d081df8`](https://github.com/mrjk/python-project-poetry-template/commit/d081df8af0307c57e209623c865ad2f2ee4e6d72))
* New feat ([`b1e92d4`](https://github.com/mrjk/python-project-poetry-template/commit/b1e92d487d1f1106fde81eda947fb0ef258dfa99))
* New feat ([`9d273d2`](https://github.com/mrjk/python-project-poetry-template/commit/9d273d22ccc85b2810d517c49fa057f4aa024919))

### Fix
* Simple bug ([`7a3a63b`](https://github.com/mrjk/python-project-poetry-template/commit/7a3a63bfb29f6f034a02fb29360a192c4b436171))
* Simple bug ([`5a5bbfc`](https://github.com/mrjk/python-project-poetry-template/commit/5a5bbfc1d7eb206f4204dfa681b243eae84c9029))
* Simple bug ([`a68988b`](https://github.com/mrjk/python-project-poetry-template/commit/a68988bc9738d5fb55bab28736fba12435f66f30))

## v0.6.0-beta.1 (2022-11-16)
### Feature
* New feat ([`d10ffc7`](https://github.com/mrjk/python-project-poetry-template/commit/d10ffc760cf55c318b548b795be33d75e308f147))
* New feat ([`1ac722b`](https://github.com/mrjk/python-project-poetry-template/commit/1ac722b3b9365abea433e8648dd77d4034b21d7b))
* New feat ([`d33b277`](https://github.com/mrjk/python-project-poetry-template/commit/d33b277a02fa580d5855dd0eaca27c53f4c25d54))

### Fix
* Simple bug ([`8617894`](https://github.com/mrjk/python-project-poetry-template/commit/861789417b4b9feba5981fbb3e4abff16f018616))
* Simple bug ([`268a40c`](https://github.com/mrjk/python-project-poetry-template/commit/268a40cc3e403a7f3b0edf139dcb468639011a5b))
* Simple bug ([`a41de80`](https://github.com/mrjk/python-project-poetry-template/commit/a41de809214a56b427422fcc3a13194d47fcdd3a))

## v0.5.0 (2022-11-16)


## v0.5.0-beta.6 (2022-11-16)
### Feature
* New feat ([`4e3499c`](https://github.com/mrjk/python-project-poetry-template/commit/4e3499cfde2f3dac741ed14515c3329be6307e4c))
* New feat ([`b70bf17`](https://github.com/mrjk/python-project-poetry-template/commit/b70bf17237b048e179b58aa1b31a3ead5253d060))
* New feat ([`33249f1`](https://github.com/mrjk/python-project-poetry-template/commit/33249f17e6d6cbb40e72c7e29c1b29c25abe4685))

## v0.5.0-beta.5 (2022-11-16)
### Fix
* Simple bug ([`39ec953`](https://github.com/mrjk/python-project-poetry-template/commit/39ec953e2796b39c740b032d92910217452d190e))
* Simple bug ([`493d6bf`](https://github.com/mrjk/python-project-poetry-template/commit/493d6bf1259ef0c1107fab5b22ab88fcce96f1b9))
* Simple bug ([`50ba746`](https://github.com/mrjk/python-project-poetry-template/commit/50ba746a288c7c26675eec1cde7ec75e33848e90))

## v0.5.0-beta.4 (2022-11-16)


## v0.4.0 (2022-11-16)
### Feature
* Add new feat ([`bbe34b6`](https://github.com/mrjk/python-project-poetry-template/commit/bbe34b6b9900dffff6fb8130e9cb3fee070182ab))
* Add new feat ([`a1f995f`](https://github.com/mrjk/python-project-poetry-template/commit/a1f995fcae5efbd13bba81d30bdcec76a72d2219))
* Add new feat ([`4bd4157`](https://github.com/mrjk/python-project-poetry-template/commit/4bd41576dd21eba7277aa81149556f7db0416f13))

### Fix
* Simple bug ([`22643a0`](https://github.com/mrjk/python-project-poetry-template/commit/22643a0161e852e73e9700ded4142e0001791276))
* Simple bug ([`d8775db`](https://github.com/mrjk/python-project-poetry-template/commit/d8775db45b43311abcc91cda4b162e9b4739ecc0))
* Simple bug ([`b389b45`](https://github.com/mrjk/python-project-poetry-template/commit/b389b45efa7913b6645136ecf63f855c0eb8ebbe))
* Simple bug ([`55e7131`](https://github.com/mrjk/python-project-poetry-template/commit/55e71318bf2c4d137456e899c0c2b13d67d06178))
* Simple bug ([`ada9df6`](https://github.com/mrjk/python-project-poetry-template/commit/ada9df6840e455bb937170c4baea812d0c49275b))
